@@ -1,7 +1,11 @@
 package TAP::Base;
 
 use strict;
-use vars qw($VERSION);
+use vars qw($VERSION @ISA);
+
+use TAP::Object;
+
+@ISA = qw(TAP::Object);
 
 =head1 NAME
 
@@ -9,11 +13,11 @@ TAP::Base - Base class that provides common functionality to L<TAP::Parser> and
 
 =head1 VERSION
 
-Version 3.11
+Version 3.13
 
 =cut
 
-$VERSION = '3.11';
+$VERSION = '3.13';
 
 my $GOT_TIME_HIRES;
 
@@ -116,14 +120,6 @@ sub _make_callback {
     return map { $_->(@_) } @$cb;
 }
 
-sub _croak {
-    my ( $self, $message ) = @_;
-    require Carp;
-    Carp::croak($message);
-
-    return;
-}
-
 =head3 C<get_time>
 
 Return the current time using Time::HiRes if available.
