@@ -1,11 +1,12 @@
 package TAP::Formatter::Color;
 
 use strict;
-
-use vars qw($VERSION);
+use vars qw($VERSION @ISA);
 
 use constant IS_WIN32 => ( $^O =~ /^(MS)?Win32$/ );
 
+@ISA = qw(TAP::Object);
+
 my $NO_COLOR;
 
 BEGIN {
@@ -70,11 +71,11 @@ TAP::Formatter::Color - Run Perl test scripts with color
 
 =head1 VERSION
 
-Version 3.11
+Version 3.13
 
 =cut
 
-$VERSION = '3.11';
+$VERSION = '3.13';
 
 =head1 DESCRIPTION
 
@@ -106,18 +107,20 @@ L<Term::ANSIColor> is not installed, returns undef.
 
 =cut
 
-sub new {
-    my $class = shift;
+# new() implementation supplied by TAP::Object
+
+sub _initialize {
+    my $self = shift;
 
     if ($NO_COLOR) {
 
         # shorten that message a bit
         ( my $error = $NO_COLOR ) =~ s/ in \@INC .*//s;
         warn "Note: Cannot run tests in color: $error\n";
-        return;
+        return;    # abort object construction
     }
 
-    return bless {}, $class;
+    return $self;
 }
 
 ##############################################################################
