@@ -36,11 +36,11 @@ TAP::Formatter::Console::Session - Harness output delegate for default console o
 
 =head1 VERSION
 
-Version 3.11
+Version 3.13
 
 =cut
 
-$VERSION = '3.11';
+$VERSION = '3.13';
 
 =head1 DESCRIPTION
 
@@ -227,6 +227,11 @@ sub _closures {
         },
 
         close_test => sub {
+
+            # Avoid circular references
+            $self->parser(undef);
+            $self->{_closures} = {};
+
             return if $really_quiet;
 
             if ($show_count) {
