@@ -1,16 +1,14 @@
 package TAP::Parser::Iterator::Process;
 
 use strict;
-
-use TAP::Parser::Iterator ();
-
 use vars qw($VERSION @ISA);
 
-@ISA = 'TAP::Parser::Iterator';
-
+use TAP::Parser::Iterator ();
 use Config;
 use IO::Handle;
 
+@ISA = 'TAP::Parser::Iterator';
+
 my $IS_WIN32 = ( $^O =~ /^(MS)?Win32$/ );
 
 =head1 NAME
@@ -19,38 +17,54 @@ TAP::Parser::Iterator::Process - Internal TAP::Parser Iterator
 
 =head1 VERSION
 
-Version 3.11
+Version 3.13
 
 =cut
 
-$VERSION = '3.11';
+$VERSION = '3.13';
 
 =head1 SYNOPSIS
 
-  use TAP::Parser::Iterator;
-  my $it = TAP::Parser::Iterator::Process->new(@args);
+  # see TAP::Parser::IteratorFactory for preferred usage
 
+  # to use directly:
+  use TAP::Parser::Iterator::Process;
+  my %args = (
+   command  => ['python', 'setup.py', 'test'],
+   merge    => 1,
+   setup    => sub { ... },
+   teardown => sub { ... },
+  );
+  my $it   = TAP::Parser::Iterator::Process->new(\%args);
   my $line = $it->next;
 
-Originally ripped off from L<Test::Harness>.
-
 =head1 DESCRIPTION
 
-B<FOR INTERNAL USE ONLY!>
+This is a simple iterator wrapper for executing external processes, used by
+L<TAP::Parser>.  Unless you're subclassing, you probably won't need to use
+this module directly.
 
-This is a simple iterator wrapper for processes.
+=head1 METHODS
 
 =head2 Class Methods
 
 =head3 C<new>
 
-Create an iterator.
+Create an iterator.  Expects one argument containing a hashref of the form:
+
+   command  => \@command_to_execute
+   merge    => $attempt_merge_stderr_and_stdout?
+   setup    => $callback_to_setup_command
+   teardown => $callback_to_teardown_command
+
+Tries to uses L<IPC::Open3> & L<IO::Select> to communicate with the spawned
+process if they are available.  Falls back onto C<open()>.
 
 =head2 Instance Methods
 
 =head3 C<next>
 
-Iterate through it, of course.
+Iterate through the process output, of course.
 
 =head3 C<next_raw>
 
@@ -95,9 +109,10 @@ sub _use_open3 {
     }
 }
 
-sub new {
-    my $class = shift;
-    my $args  = shift;
+# new() implementation supplied by TAP::Object
+
+sub _initialize {
+    my ( $self, $args ) = @_;
 
     my @command = @{ delete $args->{command} || [] }
       or die "Must supply a command to execute";
@@ -114,7 +129,7 @@ sub new {
 
     my $out = IO::Handle->new;
 
-    if ( $class->_use_open3 ) {
+    if ( $self->_use_open3 ) {
 
         # HOTPATCH {{{
         my $xclose = \&IPC::Open3::xclose;
@@ -158,14 +173,12 @@ sub new {
           or die "Could not execute ($command): $!";
     }
 
-    my $self = bless {
-        out        => $out,
-        err        => $err,
-        sel        => $sel,
-        pid        => $pid,
-        exit       => undef,
-        chunk_size => $chunk_size,
-    }, $class;
+    $self->{out}        = $out;
+    $self->{err}        = $err;
+    $self->{sel}        = $sel;
+    $self->{pid}        = $pid;
+    $self->{exit}       = undef;
+    $self->{chunk_size} = $chunk_size;
 
     if ( my $teardown = delete $args->{teardown} ) {
         $self->{teardown} = sub {
@@ -298,6 +311,10 @@ sub _finish {
 
     my $status = $?;
 
+    # Avoid circular refs
+    $self->{_next} = sub {return}
+      if $] >= 5.006;
+
     # If we have a subprocess we need to wait for it to terminate
     if ( defined $self->{pid} ) {
         if ( $self->{pid} == waitpid( $self->{pid}, 0 ) ) {
@@ -344,3 +361,17 @@ sub get_select_handles {
 }
 
 1;
+
+=head1 ATTRIBUTION
+
+Originally ripped off from L<Test::Harness>.
+
+=head1 SEE ALSO
+
+L<TAP::Object>,
+L<TAP::Parser>,
+L<TAP::Parser::Iterator>,
+L<TAP::Parser::IteratorFactory>,
+
+=cut
+
