@@ -1,10 +1,12 @@
 package TAP::Parser::YAMLish::Reader;
 
 use strict;
+use vars qw($VERSION @ISA);
 
-use vars qw{$VERSION};
+use TAP::Object ();
 
-$VERSION = '3.11';
+@ISA     = 'TAP::Object';
+$VERSION = '3.13';
 
 # TODO:
 #   Handle blessed object syntax
@@ -22,11 +24,7 @@ my $IS_HASH_KEY  = qr{ ^ [\w\'\"] }x;
 my $IS_END_YAML  = qr{ ^ \.\.\. \s* $ }x;
 my $IS_QQ_STRING = qr{ ^ $QQ_STRING $ }x;
 
-# Create an empty TAP::Parser::YAMLish::Reader object
-sub new {
-    my $class = shift;
-    bless {}, $class;
-}
+# new() implementation supplied by TAP::Object
 
 sub read {
     my $self = shift;
@@ -272,7 +270,7 @@ TAP::Parser::YAMLish::Reader - Read YAMLish data from iterator
 
 =head1 VERSION
 
-Version 3.11
+Version 3.13
 
 =head1 SYNOPSIS
 
